@@ -2,6 +2,9 @@ from naas.runner.env_var import n_env
 import urllib.parse
 import requests
 import os
+from os import path
+import pathlib
+
 
 __jup_def_set_workspace = "/etc/naas/custom/set_workspace.json"
 __jup_def_set_workspace_browser = "/etc/naas/custom/set_workspace_browser.json"
@@ -12,6 +15,16 @@ __github_api_url = "https://api.github.com/repos/{REPO}/git/trees/{BRANCH}?recur
 __github_base_url = "https://github.com/{REPO}/blob/{BRANCH}/"
 
 
+def __generate_unique_path(filepath):
+    count = 1
+    unique_path = filepath
+    while path.exists(unique_path):
+        p = pathlib.Path(filepath)
+        unique_path = path.join(p.parents[0], f"{p.stem}_({count}){p.suffix}")
+        count += 1
+    return unique_path
+
+
 def download_file(url, file_name=None):
     raw_target = url
     if not file_name:
@@ -20,7 +33,7 @@ def download_file(url, file_name=None):
     elif file_name not in ".":
         file_name = f"{file_name}.ipynb"
 
-    file_name = f"dl_{file_name}"
+    file_name = f"{file_name}"
     if "://github.com" in raw_target:
         raw_target = raw_target.replace(
             "https://github.com/", "https://raw.githubusercontent.com/"
@@ -48,28 +61,13 @@ def download_file(url, file_name=None):
         content = r.content
     if content.startswith(b"ERROR"):
         file_name = "dl_error.txt"
+    file_name = __generate_unique_path(file_name)
     with open(file_name, "wb") as f:
         f.write(content)
         f.close()
     return file_name
 
 
-def wp_set_for_open_filebrowser(url):
-    try:
-        filename = url.split("/")[-1]
-        filename = filename.split(".")[0]
-        new_wp = os.path.join(n_env.path_naas_folder, f"{filename}_workspace.json")
-        with open(__jup_def_set_workspace_browser, "r") as fh:
-            content_wp = fh.read()
-            new_content_wp = content_wp.replace("{NB_NAME}", filename)
-            with open(new_wp, "w+") as f:
-                f.write(new_content_wp)
-        os.system(f"{__jup_load_workspace} {new_wp}")
-        os.remove(new_wp)
-    except Exception as e:
-        print("Cannot config jupyter workspace", e)
-
-
 def __wp_set_for_open(url):
     try:
         filename_full = url.split("/")[-1]
@@ -110,7 +108,7 @@ def __get_onboarding_list():
     return url_list
 
 
-def init_onborading():
+def init_onboarding():
     #  jupyter lab workspaces import file_name.json
     try:
         if os.path.exists(n_env.custom_path):
