@@ -1,8 +1,18 @@
-from naas.ntypes import t_notebook, t_health, t_error, t_start, t_delete
+from naas.ntypes import (
+    t_notebook,
+    t_health,
+    t_error,
+    t_start,
+    t_delete,
+    t_out_of_credits,
+)
 from sanic.views import HTTPMethodView
 from sanic.exceptions import ServerError
 import urllib
 import uuid
+import os
+from naas_drivers import naascredits
+import pydash as _
 
 
 def parse_data(request):
@@ -40,6 +50,23 @@ class NbController(HTTPMethodView):
             file_filepath = job.get("path")
             cur_job = job.copy()
             cur_job["params"] = {**(job.get("params", dict())), **(data)}
+            if not os.environ.get(
+                "JUPYTERHUB_API_TOKEN"
+            ) is None and "app.naas.ai" in os.environ.get("JUPYTERHUB_URL", ""):
+                if _.get(naascredits.connect().get_balance(), "balance") <= 0:
+                    self.__logger.info(
+                        {
+                            "id": uid,
+                            "type": t_notebook,
+                            "status": t_out_of_credits,
+                            "filepath": file_filepath,
+                            "token": token,
+                        }
+                    )
+                    raise ServerError(
+                        {"error": "Out of credits"},
+                        status_code=401,
+                    )
             self.__logger.info(
                 {
                     "id": uid,
